@@ -8,9 +8,9 @@ import (
 )
 
 var (
-	ErrNotAuthorized    = errors.New("Not allowed to upload result to Load Impact cloud")
-	ErrNotAuthenticated = errors.New("Failed to authenticate with Load Impact cloud")
-	ErrUnknown          = errors.New("An error occurred talking to Load Impact cloud")
+	errNotAuthorized    = errors.New("not allowed to upload result to k6 Cloud")
+	errNotAuthenticated = errors.New("failed to authenticate with k6 Cloud")
+	errUnknown          = errors.New("an error occurred communicating with k6 Cloud")
 )
 
 // ErrorResponse represents an error cause by talking to the API
