@@ -216,11 +216,36 @@ func (mi *ModuleInstance) newVUInfo() (*goja.Object, error) {
 	if err != nil {
 		return o, err
 	}
-
-	err = o.Set("tags", rt.NewDynamicObject(&tagsDynamicObject{
+	tagsDynamicObject := rt.NewDynamicObject(&tagsDynamicObject{
 		runtime: rt,
 		state:   vuState,
-	}))
+	})
+
+	// This is kept for backwards compatibility reasons, but should be deprecated,
+	// since tags are also accessible via vu.metrics.tags.
+	err = o.Set("tags", tagsDynamicObject)
+	if err != nil {
+		return o, err
+	}
+	metrics, err := newInfoObj(rt, map[string]func() interface{}{
+		"tags": func() interface{} { return tagsDynamicObject },
+		"metadata": func() interface{} {
+			return rt.NewDynamicObject(&metadataDynamicObject{
+				runtime: rt,
+				state:   vuState,
+			})
+		},
+	})
+	if err != nil {
+		return o, err
+	}
+
+	err = o.Set("metrics", metrics)
+
+	if err != nil {
+		return o, err
+	}
+
 	return o, err
 }
 
@@ -311,9 +336,6 @@ func (o *tagsDynamicObject) Get(key string) goja.Value {
 	if tag, ok := tcv.Tags.Get(key); ok {
 		return o.runtime.ToValue(tag)
 	}
-	if metadatum, ok := tcv.Metadata[key]; ok {
-		return o.runtime.ToValue(metadatum)
-	}
 	return nil
 }
 
@@ -321,10 +343,8 @@ func (o *tagsDynamicObject) Get(key string) goja.Value {
 // and Number types are implicitly converted to the goja's relative string
 // representation. An exception is raised in case a denied type is provided.
 func (o *tagsDynamicObject) Set(key string, val goja.Value) bool {
-	var err error
 	o.state.Tags.Modify(func(tagsAndMeta *metrics.TagsAndMeta) {
-		err = common.ApplyCustomUserTag(o.runtime, tagsAndMeta, key, val)
-		if err != nil {
+		if err := common.ApplyCustomUserTag(tagsAndMeta, key, val); err != nil {
 			panic(o.runtime.NewTypeError(err.Error()))
 		}
 	})
@@ -337,9 +357,6 @@ func (o *tagsDynamicObject) Has(key string) bool {
 	if _, ok := ctv.Tags.Get(key); ok {
 		return true
 	}
-	if _, ok := ctv.Metadata[key]; ok {
-		return true
-	}
 	return false
 }
 
@@ -362,6 +379,59 @@ func (o *tagsDynamicObject) Keys() []string {
 	for k := range tagsMap {
 		keys = append(keys, k)
 	}
+	return keys
+}
+
+type metadataDynamicObject struct {
+	runtime *goja.Runtime
+	state   *lib.State
+}
+
+// Get a property value for the key. May return nil if the property does not exist.
+func (o *metadataDynamicObject) Get(key string) goja.Value {
+	tcv := o.state.Tags.GetCurrentValues()
+	if metadatum, ok := tcv.Metadata[key]; ok {
+		return o.runtime.ToValue(metadatum)
+	}
+	return nil
+}
+
+// Set a property value for the key. It returns true if successful. String, Boolean
+// and Number types are implicitly converted to the goja's relative string
+// representation. An exception is raised in case a denied type is provided.
+func (o *metadataDynamicObject) Set(key string, val goja.Value) bool {
+	o.state.Tags.Modify(func(tagsAndMeta *metrics.TagsAndMeta) {
+		if err := common.ApplyCustomUserMetadata(tagsAndMeta, key, val); err != nil {
+			panic(o.runtime.NewTypeError(err.Error()))
+		}
+	})
+	return true
+}
+
+// Has returns true if the property exists.
+func (o *metadataDynamicObject) Has(key string) bool {
+	ctv := o.state.Tags.GetCurrentValues()
+	if _, ok := ctv.Metadata[key]; ok {
+		return true
+	}
+	return false
+}
+
+// Delete deletes the property for the key. It returns true on success (note,
+// that includes missing property).
+func (o *metadataDynamicObject) Delete(key string) bool {
+	o.state.Tags.Modify(func(tagsAndMeta *metrics.TagsAndMeta) {
+		tagsAndMeta.DeleteMetadata(key)
+	})
+	return true
+}
+
+// Keys returns a slice with all existing property keys. The order is not
+// deterministic.
+func (o *metadataDynamicObject) Keys() []string {
+	ctv := o.state.Tags.GetCurrentValues()
+
+	keys := make([]string, 0, len(ctv.Metadata))
 	for k := range ctv.Metadata {
 		keys = append(keys, k)
 	}
