@@ -1,23 +1,3 @@
-/*
- *
- * k6 - a next-generation load testing tool
- * Copyright (C) 2021 Load Impact
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
-
 package json
 
 import (
@@ -28,9 +8,7 @@ import (
 	"time"
 
 	"github.com/klauspost/compress/gzip"
-
 	"github.com/mailru/easyjson/jwriter"
-
 	"github.com/sirupsen/logrus"
 
 	"go.k6.io/k6/metrics"
@@ -52,7 +30,7 @@ type Output struct {
 	out         io.Writer
 	closeFn     func() error
 	seenMetrics map[string]struct{}
-	thresholds  map[string][]*metrics.Threshold
+	thresholds  map[string]metrics.Thresholds
 }
 
 // New returns a new JSON output.
@@ -132,11 +110,13 @@ func (o *Output) Stop() error {
 
 // SetThresholds receives the thresholds before the output is Start()-ed.
 func (o *Output) SetThresholds(thresholds map[string]metrics.Thresholds) {
-	ths := make(map[string][]*metrics.Threshold)
+	if len(thresholds) == 0 {
+		return
+	}
+	o.thresholds = make(map[string]metrics.Thresholds, len(thresholds))
 	for name, t := range thresholds {
-		ths[name] = append(ths[name], t.Thresholds...)
+		o.thresholds[name] = t
 	}
-	o.thresholds = ths
 }
 
 func (o *Output) flushMetrics() {
@@ -149,7 +129,6 @@ func (o *Output) flushMetrics() {
 		count += len(samples)
 		for _, sample := range samples {
 			sample := sample
-			sample.Metric.Thresholds.Thresholds = o.thresholds[sample.Metric.Name]
 			o.handleMetric(sample.Metric, jw)
 			wrapSample(sample).MarshalEasyJSON(jw)
 			jw.RawByte('\n')
@@ -171,6 +150,19 @@ func (o *Output) handleMetric(m *metrics.Metric, jw *jwriter.Writer) {
 	}
 	o.seenMetrics[m.Name] = struct{}{}
 
-	wrapMetric(m).MarshalEasyJSON(jw)
+	wrapped := metricEnvelope{
+		Type:   "Metric",
+		Metric: m.Name,
+	}
+	wrapped.Data.Name = m.Name
+	wrapped.Data.Type = m.Type
+	wrapped.Data.Contains = m.Contains
+	wrapped.Data.Submetrics = m.Submetrics
+
+	if ts, ok := o.thresholds[m.Name]; ok {
+		wrapped.Data.Thresholds = ts
+	}
+
+	wrapped.MarshalEasyJSON(jw)
 	jw.RawByte('\n')
 }
